.onAttach <- function(libname, pkgname) {
  packageStartupMessage("
##############################
##         WELCOME TO       ##
##         __________       ##
##        / _  / / _ |      ##
##       / , _/ / __ |      ##
##      /_/|_/_/_/ |_|      ##
## RADIOMICS IMAGE ANALYSIS ##
##    M\U00E1rton Kolossv\U00E1ry     ##
##############################

Please cite: 
M\U00E1rton KOLOSSV\U00C1RY et al.
Radiomic Features Are Superior to Conventional Quantitative Computed Tomographic
Metrics to Identify Coronary Plaques With Napkin-Ring Sign
Circulation: Cardiovascular Imaging (2017).
DOI: 10.1161/circimaging.117.006843

M\U00E1rton KOLOSSV\U00C1RY et al.
Cardiac Computed Tomography Radiomics: A Comprehensive Review on Radiomic Techniques.
Journal of Thoracic Imaging (2017).
DOI: 10.1097/RTI.0000000000000268

Please check for updates regularly for bug fixes and new functionalities!
                        
")
}
